<?php
/**
 * Linden functions and definitions
 *
 * @package Linden Lite
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 1000; /* pixels */
}

if ( ! function_exists( 'linden_lite_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function linden_lite_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Linden, use a find and replace
	 * to change 'linden-lite' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'linden-lite', trailingslashit( get_template_directory() ) . 'languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'linden-lite-post-feed-thumb', 605, 485, true ); // (cropped)
	add_image_size( 'linden-lite-post-thumb', 1400, 740, true ); // (cropped)
	add_image_size( 'linden-lite-post-homepage-thumb', 575, 525, true);

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary Menu', 'linden-lite' )
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'linden_lite_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );

	// Editor styles
	add_editor_style( array( 'editor-style.css', linden_lite_fonts_url() ) );

	// Theme logo
	add_theme_support( 'custom-logo', array(
		'flex-width'  => true,
		'header-text' => array( 'site-title', 'site-description' ),
	) );
}
endif; // linden_lite_setup
add_action( 'after_setup_theme', 'linden_lite_setup' );

/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function linden_lite_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'linden-lite' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Widget', 'linden-lite' ),
		'id'            => 'footer-widget-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'linden_lite_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function linden_lite_scripts() {
	wp_enqueue_style( 'linden-lite-style', get_stylesheet_uri() );

	wp_enqueue_style( 'linden-lite-font-awesome-css', trailingslashit( get_template_directory_uri() ) . 'inc/fontawesome/font-awesome.css', array(), '4.7.0', 'screen' );

	wp_enqueue_script( 'linden-lite-navigation', trailingslashit( get_template_directory_uri() ) . 'js/navigation.js', array(), '20120206', true );

	wp_enqueue_script( 'linden-lite-skip-link-focus-fix', trailingslashit( get_template_directory_uri() ) . 'js/skip-link-focus-fix.js', array(), '20130115', true );

	wp_enqueue_script( 'linden-lite-scripts', trailingslashit( get_template_directory_uri() ) . 'js/scripts.js', array('jquery'), '20150706', true );

	wp_enqueue_script( 'linden-lite-sub-menu-toggle-script', trailingslashit( get_template_directory_uri() ) . 'js/sub-menu-toggle.js', array('jquery'), '20150816', true );
	wp_localize_script( 'linden-lite-sub-menu-toggle-script', 'screenReaderText', array(
		'expand'   => '<span class="screen-reader-text">' . __( 'expand child menu', 'linden-lite' ) . '</span>',
		'collapse' => '<span class="screen-reader-text">' . __( 'collapse child menu', 'linden-lite' ) . '</span>',
	) );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}


}
add_action( 'wp_enqueue_scripts', 'linden_lite_scripts' );

function linden_lite_admin_enqueue_scripts() {

	wp_enqueue_script( 'linden-lite-plugin-enhancements', trailingslashit( get_template_directory_uri() ) . 'js/plugin-enhancements.js', array('jquery'), false, true );
	}

add_action( 'admin_enqueue_scripts', 'linden_lite_admin_enqueue_scripts' );


/**
 * Custom template tags for this theme.
 */
require trailingslashit( get_template_directory() ) . 'inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require trailingslashit( get_template_directory() ) . 'inc/extras.php';

/**
 * Customizer additions.
 */
require trailingslashit( get_template_directory() ) . 'inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require trailingslashit( get_template_directory() ) . 'inc/jetpack.php';

/**
 * Load plugin enhancement file to display admin notices.
 */
require trailingslashit( get_template_directory() ) . 'inc/plugin-enhancements.php';

/**
 * Load About Me widgets
 */
require trailingslashit( get_template_directory() ) . 'inc/about-me-widget.php';

/**
 * Load the Getting Started page and Theme Update class
 */
if( is_admin() ) {
	require_once( trailingslashit( get_template_directory() ) . 'inc/admin/start-page/start-page.php' );
}

/**
 * Load Customizer Upgrade button
 */
require_once( trailingslashit( get_template_directory() ) . 'inc/nudge-upgrade-theme/add-customize-section.php' );

 /**
 *
 * Build Google font url based on
 * http://themeshaper.com/2014/08/13/how-to-add-google-fonts-to-wordpress-themes/
 *
 */
function linden_lite_fonts_url() {
	$fonts_url = '';

	/* Translators: If there are characters in your language that are not
    * supported by Open Sans, translate this to 'off'. Do not translate
    * into your own language.
    */

	$opensans = _x( 'on', 'Open Sans font: on or off', 'linden-lite' );

	$yrsa = _x( 'on', 'Yrsa font: on or off', 'linden-lite' );

	if ( 'off' !== $opensans ||  'off' !== $libre ||  'off' !== $lora ) {
		$font_families = array();

		if ( 'off' !== $opensans ) {
			$font_families[] = 'Source Sans Pro:300,700';
		}

		if ( 'off' !== $yrsa) {
			$font_families[] = 'Yrsa:400';
		}

		$query_args = array(
			'family' => urlencode( implode( '|', $font_families ) ),
			'subset' => urlencode( 'latin,latin-ext' ),
		);

		$fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
	}

	return $fonts_url;
}

/**
 * Enqueue Google font on front end
 */
function linden_lite_scripts_styles() {
	wp_enqueue_style( 'linden-lite-fonts', linden_lite_fonts_url(), array(), null );
}
add_action( 'wp_enqueue_scripts', 'linden_lite_scripts_styles' );


if ( ! function_exists( 'linden_lite_excerpt_more' ) && ! is_admin() ) :

/**
 *
 * Linden read more
 * Replaces "[...]" (appended to automatically generated excerpts) with ... and a 'read more' link.
 * @return string 'read more link
 *
 */
function linden_lite_excerpt_more( $more ) {
	$link = sprintf( '<p class="read-more-wrap"><a href="%1$s" class="read-more">%2$s &rarr;</a></p>',
			esc_url( get_permalink( get_the_ID() ) ),
			sprintf( __( 'Read more %s', 'linden-lite' ), '<span class="screen-reader-text">' . get_the_title( get_the_ID() ) . '</span>' )
		);
	return $link;
	}
add_filter( 'excerpt_more', 'linden_lite_excerpt_more' );
endif;


if ( ! function_exists( 'linden_lite_manual_excerpt' ) && ! is_admin() ) :

/**
 *
 * Linden 'read more' link for manual excerpt
 *
 */
function linden_lite_manual_excerpt($excerpt) {
	$excerpt_more = '';
	if( has_excerpt() ) {
		$excerpt_more = sprintf( '<p class="read-more-wrap"><a href="%1$s" class="read-more">%2$s &rarr;</a></p>',
			esc_url( get_permalink( get_the_ID() ) ),
			sprintf( __( 'Read more %s', 'linden-lite' ), '<span class="screen-reader-text">' . get_the_title( get_the_ID() ) . '</span>' )
		);
	}
	return $excerpt . $excerpt_more;
}
add_filter('get_the_excerpt', 'linden_lite_manual_excerpt');
endif;


if ( ! function_exists( 'linden_lite_author_bio' ) ) :

/**
 * Display author info
 */
function linden_lite_author_bio() {

	if( get_theme_mod('linden_lite_author_bio', 1) !== 1 ){
		return;
	}
	?>

	<div class="entry-author">
	<div class="author-avatar"><?php
		echo get_avatar( get_the_author_meta( 'user_email' ), 100);
		?></div><!-- .author-avatar -->
	<div class="author-info">
		<div class="author-heading">
			<h2 class="author-title"><a class="author-name author-link" href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>;?>"><?php echo get_the_author_meta('display_name');?></a></h2>
		</div><!-- .author-heading -->

		<div class="author-bio">
			<?php echo get_the_author_meta('description');?>
		</div><!-- .author-bio -->
	</div><!-- .author-info -->

	</div><?php
}
endif;