<?php

/**
 * This template adds the Getting Started page.
 *
 * @package WordPress
 * @subpackage linden-lite
 */


/**
 * Load Getting Started styles in the admin
 */
function linden_lite_start_page_admin_scripts() {

	// Load styles only on our page
	global $pagenow;
	if( 'themes.php' != $pagenow )
		return;

	// Start Page styles
	wp_register_style( 'start-page', get_template_directory_uri() . '/inc/admin/start-page/start-page.css', false, '1.0.0' );
	wp_enqueue_style( 'start-page' );

}
add_action( 'admin_enqueue_scripts', 'linden_lite_start_page_admin_scripts' );

//Add the theme info page
if (!function_exists('linden_lite_add_start_page')) {
	function linden_lite_add_start_page() {
		add_theme_page(__('Theme Start Page', 'linden-lite'), __('Theme Start Page', 'linden-lite'), 'edit_theme_options', 'start-page.php', 'linden_lite_info_page');
	}
}
add_action('admin_menu', 'linden_lite_add_start_page');


if (!function_exists('linden_lite_info_page')) {
	function linden_lite_info_page() {
		$theme_data = wp_get_theme(); ?>

	<div class="wrap about-wrap nudge-themes-start-page">
		<img class="theme-screenshot" src="<?php echo get_template_directory_uri() . '/screenshot.png'; ?>" alt="" />
		<h1><?php printf(__('Welcome to %1$s %2$s', 'linden-lite'), $theme_data->Name, $theme_data->Version ); ?></h1>
		<p class="sub-heading"><?php printf( __('Thanks for downloading %s!', 'linden-lite'), $theme_data->Name ); ?>
		<?php echo $theme_data->Description; ?></p>

		<div class="postbox my-form-wrap feature-section">
			<h2 ><?php printf( __('Getting Started with %s', 'linden-lite'), $theme_data->Name ); ?></h2>

			<div class="feature-section two-col">
				<div class="col">
						<div class="media-container">
							<img src="<?php echo get_template_directory_uri() . '/inc/admin/start-page/images/docs-linden-docs.png'; ?>">
						</div>

					</div>
				<div class="col">
					<h3><?php printf( __('Documentation', 'linden-lite')); ?></h3>
						<p><?php printf( __('Need help setting up Linden Lite? Take a look at the documentation for help on getting setup.', 'linden-lite')); ?></p>
						<a href="https://nudgethemes.com/documentation/" class="button button-primary" target="_blank"><?php printf( __('Go to the Documentation', 'linden-lite')); ?></a>
				</div>
			</div>
		</div>

		<div class="postbox my-form-wrap feature-section">
			<h2 id="lindend-upgrade"><?php printf( __('Upgrade to Linden', 'linden-lite')); ?></h2>
			<p class="upgrade-btn-wrap"><?php printf( __('Upgrading to <a href="https://nudgethemes.com/wordpress-themes/linden-theme/" target="_blank">Linden</a> allows lets you customize your site\'s fonts and colors. It also includes a Feautred Post slider using <a href="http://jetpack.me/" target="_blank"> Jetpack</a> as well as a built in Instagram widget.', 'linden-lite'));?><br><a href="https://nudgethemes.com/wordpress-themes/linden-theme/" class="button button-primary button-upgrade" target="_blank"><?php printf( __('Upgrade to Linden', 'linden-lite')); ?></a></p>

			<div class="feature-section two-col">
				<div class="col">
					<div class="media-container">
						<img src="<?php echo get_template_directory_uri() . '/inc/admin/start-page/images/linden-features-featured-post-slider.png'; ?>">
					</div>
					<h3><?php printf( __('Featured Post Slider', 'linden-lite')); ?></h3>
					<p><?php printf( __('Highlight up to five of your best posts, pages or portfolio items using Jetpack\'s Featured Content. The full-width slider automatically appears on your blog\'s homepage or Portfolio homepage template.', 'linden-lite')); ?></p>
				</div>
				<div class="col">
					<div class="media-container">
						<img src="<?php echo get_template_directory_uri() . '/inc/admin/start-page/images/linden-features-custom-fonts.png'; ?>">
					</div>
					<h3><?php printf( __('Custom Fonts', 'linden-lite')); ?></h3>
					<p><?php printf( __('With Linden, you can easily set your own free Google font directly from the theme. No need to install an additional plugin!', 'linden-lite')); ?></p>
				</div>
				<div class="col">
					<div class="media-container">
						<img src="<?php echo get_template_directory_uri() . '/inc/admin/start-page/images/linden-features-ig-widget.png'; ?>">
					</div>
					<h3><?php printf( __('Built-In Instagram Widget', 'linden-lite')); ?></h3>
					<p><?php printf( __('Linden offers a built-in Instagram widget. Place it in the full-width widget area and set the options.', 'linden-lite')); ?></p>
				</div>
				<div class="col">
					<div class="media-container">
						<img src="<?php echo get_template_directory_uri() . '/inc/admin/start-page/images/linden-features-special-styles.png'; ?>">
					</div>
					<h3><?php printf( __('Special Styles', 'linden-lite')); ?></h3>
					<p><?php printf( __('Give your content a little extra style with over hanging images, drop caps and sub-headings. Take a look at <a href="https://nudgethemes.com/documentation/linden-documentation/" target="_blank">Linden\'s documentation</a> for how easily you can create these. ', 'linden-lite')); ?></p>
				</div>
				<div class="nt-theme-upgrade clear">
					<a href="https://nudgethemes.com/wordpress-themes/linden-theme/" class="button button-primary button-upgrade" target="_blank"><?php printf( __('Upgrade to Linden', 'linden-lite')); ?></a>
				</div>
			</div>
		</div> <!-- end my-form-wrap -->
	</div>
	<?php
	}
}