<?php
/**
 * Linden Theme Customizer
 *
 * @package Linden Lite
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function linden_lite_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	$wp_customize->add_section(
		'linden_lite_theme_options',
		array(
			'title'    => esc_html__('Theme Options', 'linden-lite' ),
			'priority' => 20,
	));

	$wp_customize->add_setting(
		'linden_lite_intro_titlebox',
		array(
			'default'			=> '',
			'sanitize_callback' => 'linden_lite_sanitize_text',
	    )
	);

	$wp_customize->add_control(
		'linden_lite_intro_titlebox',
		array(
			'label'   => esc_html__('Intro title', 'linden-lite' ),
			'section' => 'linden_lite_theme_options',
			'type'    => 'text',
		)
	);

	$wp_customize->add_setting(
		'linden_lite_intro_textbox',
		array(
			'default'			=> '',
			'sanitize_callback' => 'linden_lite_sanitize_text',
	    )
	);

	$wp_customize->add_control(
		'linden_lite_intro_textbox',
		array(
			'label'   => esc_html__('Intro text', 'linden-lite' ),
			'section' => 'linden_lite_theme_options',
			'type'    => 'textarea',
		)
	);

	$wp_customize->add_setting(
		'linden_lite_intro_textbox_pos',
		array(
			'default' 			=> 'intro-text-left',
			'sanitize_callback' => 'linden_lite_sanitize_position',
		)
	);

	$wp_customize->add_control(
		'linden_lite_intro_textbox_pos',
		array(
			'label'   => esc_html__('Intro text position', 'linden-lite' ),
			'section' => 'linden_lite_theme_options',
			'type'    => 'radio',
			'choices' => array(
						'intro-text-left'   => esc_html__('Left', 'linden-lite' ),
						'intro-text-center' => esc_html__('Center', 'linden-lite' ),
						'intro-text-right'  => esc_html__('Right', 'linden-lite' ),
					),
		)
	);

	$wp_customize->add_setting(
		'linden_lite_sidebar_pos',
		array(
			'default'			=> 'sidebar-left',
			'sanitize_callback' => 'linden_lite_sanitize_position',
		)
	);

	$wp_customize->add_control(
		'linden_lite_sidebar_pos',
		array(
			'label'   => esc_html__('Post sidebar position', 'linden-lite' ),
			'section' => 'linden_lite_theme_options',
			'type'    => 'radio',
			'choices' => array(
						'sidebar-left'   => esc_html__('Left', 'linden-lite' ),
						'sidebar-right'  => esc_html__('Right', 'linden-lite' ),
						'sidebar-none'   => esc_html__('None', 'linden-lite' ),
					),
		)
	);


	//author bio
	$wp_customize->add_setting(
		'linden_lite_author_bio',
		array(
			'default'			=> 1,
			'sanitize_callback' => 'linden_lite_sanitize_checkbox'
		)
	);

	$wp_customize->add_control(
		'linden_lite_author_bio',
		array(
			'label'       => esc_html__('Display author bio on single posts', 'linden-lite' ),
			'section'     => 'linden_lite_theme_options',
			'type'        => 'checkbox'
		)
	);
}
add_action( 'customize_register', 'linden_lite_customize_register' );

/**
 * Sanitize intro text box
 */
function linden_lite_sanitize_text( $input ) {
	return wp_kses_post( force_balance_tags( trim( $input ) ) );
}

/**
 * Sanitize intro text box or sidebar position
 */
function linden_lite_sanitize_position( $input ) {

	switch($input){
		case 'intro-text-left':
		case 'intro-text-center':
		case 'intro-text-right':
		case 'sidebar-left':
		case 'sidebar-right':
		case 'sidebar-none':
			return $input;
	}

	return '';
}

/**
 * Sanitize checkbox
 */
function linden_lite_sanitize_checkbox( $input ) {
	return $input ? 1 : 0;
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function linden_lite_customize_preview_js() {
	wp_enqueue_script( 'linden-lite-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20130508', true );
}
add_action( 'customize_preview_init', 'linden_lite_customize_preview_js' );

/**
 * Customizer styles
 */
function linden_lite_customizer_style() {

	// Load styles for customizer
	wp_register_style( 'linden-lite-customizer-styles', get_template_directory_uri() . '/inc/css/customizer.css', false, '1.0' );
	wp_enqueue_style( 'linden-lite-customizer-styles' );

}
add_action( 'admin_enqueue_scripts', 'linden_lite_customizer_style' );
