<?php
/**
 * Jetpack Compatibility File
 * See: https://jetpack.me/
 *
 * @package Linden Lite
 */


/**
 * Add theme support for Infinite Scroll.
 * See: https://jetpack.me/support/infinite-scroll/
 */
function linden_lite_jetpack_setup() {
	/**
	* Add theme support for Infinite Scroll
	*/

	add_theme_support( 'infinite-scroll', array(
		'container'      => 'post-grid',
		'wrapper'        => false,
		'render'         => 'linden_lite_infinite_scroll_render',
		'footer'         => 'page',
		'footer_widgets' => array( 'footer-widget-1', 'footer-full-width-widget' ),
	) );

	/**
	* Add support for Featured Content.
	*/
	add_theme_support( 'featured-content', array(
		'featured_content_filter' => 'linden_lite_get_featured_posts',
		'max_posts' => 1,
		'post_types' => array( 'post', 'page', 'jetpack-portfolio' )
	) );

	/**
	* Add support for responsive videos.
	*/
	add_theme_support( 'jetpack-responsive-videos' );

	/**
	* Add theme support for Jetpack Portfolio.
	*/
	add_theme_support( 'jetpack-portfolio' );

	/**
	* Add Content Options
	*/
	/*
	 * add_theme_support( 'jetpack-content-options', array(
		'author-bio'   => true, // display or not the author bio: true or false
		'post-details' => array(
			'stylesheet' => 'linden-style', // name of the theme's stylesheet
			'date'       => '.posted-on', // a CSS selector matching the elements that display the post date.
			'categories' => '.cat-links', // a CSS selector matching the elements that display the post categories.
			'tags'       => '.tags-links', // a CSS selector matching the elements that display the post tags.
			'author'     => '.byline', // a CSS selector matching the elements that display the post author.
		),
	) );*/

} // end function linden_lite_jetpack_setup
add_action( 'after_setup_theme', 'linden_lite_jetpack_setup' );


function linden_lite_infinite_scroll_render() {

	while ( have_posts() ) : the_post();
		get_template_part( 'template-parts/content', get_post_format() );
	endwhile;

} // end function linden_lite_infinite_scroll_render

/**
 * Getter function for Featured Content
 */
function linden_lite_get_featured_posts() {
	$featured_posts = apply_filters( 'linden_lite_get_featured_posts', array() );
	if(is_array($featured_posts) && count($featured_posts)){
		return array_slice($featured_posts, 0,1);
	}

	return $featured_posts;
}

/**
 * Conditional function for checking if we have at least one Featured Content posts
 */
function linden_lite_has_featured_posts( $minimum = 1) {
   if ( is_paged() )
		return false;

	$minimum = absint( $minimum );
	$featured_posts = apply_filters( 'linden_lite_get_featured_posts', array() );

	if ( ! is_array( $featured_posts ) )
		return false;

	if ( $minimum > count( $featured_posts ) )
		return false;

	return true;
}

/**
 * Author Bio Avatar Size.
 */

function linden_lite_author_bio_avatar_size() {
	return 100; // in px
}
add_filter( 'jetpack_author_bio_avatar_size', 'linden_lite_author_bio_avatar_size' );
