<?php
/*
Linden_Lite_Add_Upgrade_Customize_Section is based on Justin Tadlock's '"Pro" theme section examples for the customizer'
https://github.com/justintadlock/trt-customizer-pro, (C) 2016 Justin Tadlock.
'"Pro" theme section examples for the customizer' is distributed under the terms of the GNU GPL v2 or later.
*/
final class Linden_Lite_Add_Upgrade_Customize_Section {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {
		static $instance = null;
		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}
		return $instance;
	}
	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}
	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {
		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );
		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}
	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		require_once( trailingslashit( get_template_directory() ) . 'inc/nudge-upgrade-theme/customize-section.php' );

		// Register custom section types.
		$manager->register_section_type( 'Linden_Lite_Upgrade_Customize_Section' );

		// Register sections.
		$manager->add_section(
			new Linden_Lite_Upgrade_Customize_Section(
				$manager,
				'linden-lite-upgrade-theme',
				array(
					'title'    => esc_html__( 'Linden Theme', 'linden-lite' ),
					'pro_text' => esc_html__( 'Upgrade',     'linden-lite' ),
					'pro_url'  => 'https://nudgethemes.com/wordpress-themes/linden-theme/',
					'priority'       => 1,
				)
			)
		);
	}
	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'linden-lite-upgrade-theme-customize-section', trailingslashit( get_template_directory_uri() ). 'inc/nudge-upgrade-theme/customize-section.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'linden-lite-upgrade-theme-customize-section', trailingslashit(get_template_directory_uri() ). 'inc/nudge-upgrade-theme/customize-section.css' );
	}
}

Linden_Lite_Add_Upgrade_Customize_Section::get_instance();