<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Linden Lite
 */

if ( ! function_exists( 'linden_lite_post_navigation' ) ) :
/**
 * Display navigation to next/previous post when applicable.
 *
 * @todo Remove this function when WordPress 4.3 is released.
 */
function linden_lite_post_navigation() {
	// Don't print empty markup if there's nowhere to navigate.
	$previous = ( is_attachment() ) ? get_post( get_post()->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );

	if ( ! $next && ! $previous ) {
		return;
	}

	?>
	<nav class="navigation post-navigation clear" role="navigation">
		<h2 class="screen-reader-text"><?php esc_html_e( 'Post navigation', 'linden-lite' ); ?></h2>
			<?php
				previous_post_link( ' <div class="nav-previous"><span>%link</span></div>');
				next_post_link( ' <div class="nav-next"><span>%link</span></div>');
			?>
	</nav><!-- .navigation -->
	<?php
}
endif;

if ( ! function_exists( 'linden_lite_numbered_pagination' ) ) :
/**
 * Numbered pagination for blog and archive page
 */
function linden_lite_numbered_pagination() {
	global $wp_query;

	$big = 999999999; // need an unlikely integer

	$paginate_links =  paginate_links( array(
		'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
		'format' => '?paged=%#%',
		'current' => max( 1, get_query_var('paged') ),
		'total' => $wp_query->max_num_pages,
		'prev_text'          => __('<span class="screen-reader-text">Previous</span>', 'linden-lite'),
		'next_text'          => __('<span class="screen-reader-text">Next</span>', 'linden-lite'),
	) );

	// Display the pagination if more than one page is found
	if ( $paginate_links ) {
		echo '<nav class="navigation posts-navigation numbered-pagination clear" role="navigation">';
		echo '<h2 class="screen-reader-text">'. esc_html__( 'Posts navigation', 'linden-lite' ) . '</h2>';
		echo $paginate_links;
		echo '</nav>';
	}
}
endif;

if ( ! function_exists( 'linden_lite_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time.
 */
function linden_lite_posted_on(  ) {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);

	$posted_on = '<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>';

	echo '<span class="posted-on">' . $posted_on . '</span>';

}
endif;


if ( ! function_exists( 'linden_lite_posted_by' ) ) :
	/**
	 * Prints HTML with meta information for the current post author.
	 */
	function linden_lite_posted_by(  ) {

		$byline = sprintf(
			esc_html_x( 'by %s', 'post author', 'linden-lite' ),
			'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
		);

		echo '<span class="byline"> ' . $byline . '</span>';

	}
endif;


if ( ! function_exists( 'linden_lite_entry_category' ) ) :
/**
 * Prints HTML with meta information for the categories.
 */
function linden_lite_entry_category() {
	// Hide category text for pages.
	if ( 'post' == get_post_type() ) {
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( esc_html__( ', ', 'linden-lite' ) );
		if ( $categories_list ) {
			printf( '<span class="cat-links">' . esc_html__( 'In %1$s', 'linden-lite' ) . '</span>', $categories_list );
		}
	}
}
endif;

if ( ! function_exists( 'linden_lite_entry_comments' ) ) :
/**
 * Prints HTML with comments.
 */
function linden_lite_entry_comments() {

	if ( ! post_password_required() && get_comments_number() ) {
		echo '<span class="comments-link">';
		comments_popup_link( '', esc_html__( '1 Comment', 'linden-lite' ), esc_html__( '% Comments', 'linden-lite' ) );
		echo '</span>';
	}
	edit_post_link( esc_html__( 'Edit', 'linden-lite' ), '<span class="edit-link">', '</span>' );
}
endif;


if ( ! function_exists( 'linden_lite_post_entry_tags' ) ) :
/**
 * Prints HTML with meta information for tags.
 */
function linden_lite_post_entry_tags() {
	// Hide tag text for pages.
	/* translators: used between list items, there is a space after the comma */
	$tags_list = get_the_tag_list( '', esc_html__( ' ', 'linden-lite' ) );
	if ( $tags_list ) {
		echo '<footer class="entry-footer entry-meta tags-links">';
		printf( '<span class="tags-link">%1$s</span>', $tags_list );
		echo '</footer>';
	}
}
endif;

if ( ! function_exists( 'linden_lite_portfolio_entry_tags' ) ) :
/**
 * Prints HTML with meta information for portfolio tags. ****NEED HELP WITH THIS: wrap each item in span****
 */
function linden_lite_portfolio_entry_tags() {
	global $post;

	/* translators: used between list items, there is a space after the comma */
	$portfolio_tags_list = get_the_term_list($post->ID, 'jetpack-portfolio-tag', '', ' ');

	if ( !is_wp_error( $portfolio_tags_list && $portfolio_tags_list) ) {
		$portfolio_tags_list = apply_filters( 'the_terms', $portfolio_tags_list, 'jetpack-portfolio-tag', '', ', ' );

		echo '<footer class="entry-footer entry-meta tags-links">';
		printf( '<span class="tags-links">%1$s</span>', $portfolio_tags_list );
		echo '</footer>';
	}
}
endif;


if ( ! function_exists( 'linden_lite_portfolio_entry_types' ) ) :
/**
 * Prints HTML with meta information for portfolio types. ****NEED HELP WITH THIS: wrap entire list in span****
 */
function linden_lite_portfolio_entry_types() {
	global $post;

	$portfolio_types_list = get_the_term_list($post->ID, 'jetpack-portfolio-type', '', ', ');

	if ( $portfolio_types_list && !is_wp_error( $portfolio_types_list) ) {

		$portfolio_types_list = apply_filters( 'the_terms', $portfolio_types_list, 'jetpack-portfolio-type', '', ', ' );

		printf( '<span class="types-link">'.esc_html__( 'In %1$s', 'linden-lite' ).'</span>', $portfolio_types_list );
	}

}
endif;


if ( ! function_exists( 'linden_lite_entry_category_or_types' ) ) :
	/**
	 * Prints HTML with meta information for the categories.
	 */
	function linden_lite_entry_category_or_types() {
		// Hide category text for pages.
		if ( 'post' == get_post_type() ) {

			linden_lite_entry_category();

		} elseif ('jetpack-portfolio' == get_post_type()){

			linden_lite_portfolio_entry_types();
		}
	}
endif;

if ( ! function_exists( 'linden_lite_entry_tags' ) ) :
	/**
	 * Prints HTML with meta information for the categories.
	 */
	function linden_lite_entry_tags() {
		// Hide category text for pages.
		if ( 'post' == get_post_type() ) {

			linden_lite_post_entry_tags();
		} elseif ('jetpack-portfolio' == get_post_type()){

			linden_lite_portfolio_entry_tags();
		}
	}
endif;

/**
 * Flush out the transients used in linden_lite_categorized_blog.
 */
function linden_lite_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'linden_lite_categories' );
}
add_action( 'edit_category', 'linden_lite_category_transient_flusher' );
add_action( 'save_post',     'linden_lite_category_transient_flusher' );
